==> ogre-next-2.3.3-1-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/search/functions_17.js <==
var searchData=
[
  ['x11eglcontext_0',['X11EGLContext',['../class_ogre_1_1_x11_e_g_l_context.html#ab64c62f21853a949bb655e239f035329',1,'Ogre::X11EGLContext']]],
  ['x11eglsupport_1',['X11EGLSupport',['../class_ogre_1_1_x11_e_g_l_support.html#afb18742080a07659c7fd5809be375374',1,'Ogre::X11EGLSupport']]],
  ['x11eglwindow_2',['X11EGLWindow',['../class_ogre_1_1_x11_e_g_l_window.html#ad68ece32d3ad9cd7fa573c23ede26245',1,'Ogre::X11EGLWindow']]],
  ['xallocsizehints_3',['XAllocSizeHints',['../_ogre_x11_e_g_l_support_8h.html#ad9deb13fea95cc35a47915884de38dd8',1,'OgreX11EGLSupport.h']]],
  ['xallocwmhints_4',['XAllocWMHints',['../_ogre_x11_e_g_l_support_8h.html#ad3f7e6ad839bacbf4985f2fee71fe575',1,'OgreX11EGLSupport.h']]],
  ['xaxis_5',['xaxis',['../class_ogre_1_1_array_quaternion.html#a497e06d0ba8d4d550e781446b595a159',1,'Ogre::ArrayQuaternion::xAxis(void) const'],['../class_ogre_1_1_array_quaternion.html#a497e06d0ba8d4d550e781446b595a159',1,'Ogre::ArrayQuaternion::xAxis(void) const'],['../class_ogre_1_1_array_quaternion.html#a497e06d0ba8d4d550e781446b595a159',1,'Ogre::ArrayQuaternion::xAxis(void) const'],['../class_ogre_1_1_quaternion.html#a58a45c5dd46ceee8dbf81dfced570dbe',1,'Ogre::Quaternion::xAxis()']]],
  ['xclosedisplay_6',['XCloseDisplay',['../_ogre_x11_e_g_l_support_8h.html#a10d83d1f69ba9c38afde9da17cfe2405',1,'OgreX11EGLSupport.h']]],
  ['xcreatecolormap_7',['XCreateColormap',['../_ogre_x11_e_g_l_support_8h.html#a30ae54ad919dae8588835ae717509d0f',1,'OgreX11EGLSupport.h']]],
  ['xcreatewindow_8',['XCreateWindow',['../_ogre_x11_e_g_l_support_8h.html#aa4169ce536fca992c649729b4b80c67a',1,'OgreX11EGLSupport.h']]],
  ['xdestroywindow_9',['XDestroyWindow',['../_ogre_x11_e_g_l_support_8h.html#a3f5a57ad83d1e025553b6857087b9d9b',1,'OgreX11EGLSupport.h']]],
  ['xdisplayname_10',['XDisplayName',['../_ogre_x11_e_g_l_support_8h.html#a55bef2ae3bc74aafa66949a5a31ec583',1,'OgreX11EGLSupport.h']]],
  ['xflush_11',['XFlush',['../_ogre_x11_e_g_l_support_8h.html#a71c8b3499eab93ac47d7952bdf5ec45a',1,'OgreX11EGLSupport.h']]],
  ['xfree_12',['XFree',['../_ogre_x11_e_g_l_support_8h.html#a095580a52a3e5e63f479629c092dc405',1,'OgreX11EGLSupport.h']]],
  ['xgetvisualinfo_13',['XGetVisualInfo',['../_ogre_x11_e_g_l_support_8h.html#ad14dd9fdc11e5d00ab63647cfc3f8a11',1,'OgreX11EGLSupport.h']]],
  ['xgetwindowattributes_14',['XGetWindowAttributes',['../_ogre_x11_e_g_l_support_8h.html#aa563e8e7abd73ce344907eb39dcd181a',1,'OgreX11EGLSupport.h']]],
  ['xinternatom_15',['XInternAtom',['../_ogre_x11_e_g_l_support_8h.html#a10901fada7a1cc5efba300941c79a392',1,'OgreX11EGLSupport.h']]],
  ['xmapwindow_16',['XMapWindow',['../_ogre_x11_e_g_l_support_8h.html#a257afc0c4bb459c2c660630bff44e9db',1,'OgreX11EGLSupport.h']]],
  ['xmovewindow_17',['XMoveWindow',['../_ogre_x11_e_g_l_support_8h.html#a28b3ee0966e12db6cac561ad9ef484d0',1,'OgreX11EGLSupport.h']]],
  ['xopendisplay_18',['XOpenDisplay',['../_ogre_x11_e_g_l_support_8h.html#a51c949ed3a72bf2304f018bbcdcd64f1',1,'OgreX11EGLSupport.h']]],
  ['xqueryextension_19',['XQueryExtension',['../_ogre_x11_e_g_l_support_8h.html#a477dc291ddfcb6c98b4c46dbf205a270',1,'OgreX11EGLSupport.h']]],
  ['xquerytree_20',['XQueryTree',['../_ogre_x11_e_g_l_support_8h.html#a89461d5e0614dfd557804e22100fecee',1,'OgreX11EGLSupport.h']]],
  ['xresizewindow_21',['XResizeWindow',['../_ogre_x11_e_g_l_support_8h.html#adce477cbf3a0b83f5640dd5ebf668904',1,'OgreX11EGLSupport.h']]],
  ['xrrconfigcurrentconfiguration_22',['XRRConfigCurrentConfiguration',['../_ogre_x11_e_g_l_support_8h.html#a5a05a04a82880daeeb842fe1793e3966',1,'OgreX11EGLSupport.h']]],
  ['xrrconfigcurrentrate_23',['XRRConfigCurrentRate',['../_ogre_x11_e_g_l_support_8h.html#a4af046c766176577e90f49fb42987c42',1,'OgreX11EGLSupport.h']]],
  ['xrrconfigrates_24',['XRRConfigRates',['../_ogre_x11_e_g_l_support_8h.html#af5c3b39d44706b903a2c61448a84f132',1,'OgreX11EGLSupport.h']]],
  ['xrrconfigsizes_25',['XRRConfigSizes',['../_ogre_x11_e_g_l_support_8h.html#a144fe29252ef483e8d38a935618b1a5b',1,'OgreX11EGLSupport.h']]],
  ['xrrfreescreenconfiginfo_26',['XRRFreeScreenConfigInfo',['../_ogre_x11_e_g_l_support_8h.html#a54f479b30658bd7e436f6d31339216c3',1,'OgreX11EGLSupport.h']]],
  ['xrrgetscreeninfo_27',['XRRGetScreenInfo',['../_ogre_x11_e_g_l_support_8h.html#a846a80562149754060339388f6f07a4d',1,'OgreX11EGLSupport.h']]],
  ['xrrsetscreenconfigandrate_28',['XRRSetScreenConfigAndRate',['../_ogre_x11_e_g_l_support_8h.html#a8a0543932617c1cc144b66bcd61f421d',1,'OgreX11EGLSupport.h']]],
  ['xsendevent_29',['XSendEvent',['../_ogre_x11_e_g_l_support_8h.html#a199771e2d78de41b3c8a69adaafc4db0',1,'OgreX11EGLSupport.h']]],
  ['xseterrorhandler_30',['XSetErrorHandler',['../_ogre_x11_e_g_l_support_8h.html#a188ca3ae6e59151a2c4c14a99482e97c',1,'OgreX11EGLSupport.h']]],
  ['xsetwmproperties_31',['XSetWMProperties',['../_ogre_x11_e_g_l_support_8h.html#a46c6f72b9036514969671b47377251cb',1,'OgreX11EGLSupport.h']]],
  ['xsetwmprotocols_32',['XSetWMProtocols',['../_ogre_x11_e_g_l_support_8h.html#ad15f704cba03100c7c79f536927aa6c3',1,'OgreX11EGLSupport.h']]],
  ['xstringlisttotextproperty_33',['XStringListToTextProperty',['../_ogre_x11_e_g_l_support_8h.html#a13f1bb8c8d66fd74b2d6a425d76b6716',1,'OgreX11EGLSupport.h']]],
  ['xvisualidfromvisual_34',['XVisualIDFromVisual',['../_ogre_x11_e_g_l_support_8h.html#a5c320d2dfe131dc7e450142e83ee149b',1,'OgreX11EGLSupport.h']]],
  ['xy_35',['xy',['../class_ogre_1_1_vector3.html#acdfb27b5a990112e3f731a2be8a54aec',1,'Ogre::Vector3::xy()'],['../class_ogre_1_1_vector4.html#ad6dc84f0ca8204d16b0232c7609c243c',1,'Ogre::Vector4::xy() const']]],
  ['xyz_36',['xyz',['../class_ogre_1_1_vector4.html#a299d194697fd0ab74fec1961beed0715',1,'Ogre::Vector4']]]
];

==> ogre-next-3.0.0-2-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/search/functions_17.js <==
var searchData=
[
  ['x11eglcontext_0',['X11EGLContext',['../class_ogre_1_1_x11_e_g_l_context.html#ab64c62f21853a949bb655e239f035329',1,'Ogre::X11EGLContext']]],
  ['x11eglsupport_1',['X11EGLSupport',['../class_ogre_1_1_x11_e_g_l_support.html#afb18742080a07659c7fd5809be375374',1,'Ogre::X11EGLSupport']]],
  ['x11eglwindow_2',['X11EGLWindow',['../class_ogre_1_1_x11_e_g_l_window.html#ad68ece32d3ad9cd7fa573c23ede26245',1,'Ogre::X11EGLWindow']]],
  ['xallocsizehints_3',['XAllocSizeHints',['../_ogre_x11_e_g_l_support_8h.html#ad9deb13fea95cc35a47915884de38dd8',1,'OgreX11EGLSupport.h']]],
  ['xallocwmhints_4',['XAllocWMHints',['../_ogre_x11_e_g_l_support_8h.html#ad3f7e6ad839bacbf4985f2fee71fe575',1,'OgreX11EGLSupport.h']]],
  ['xaxis_5',['xAxis',['../class_ogre_1_1_array_quaternion.html#ab9c37a58cc12f2c86f68e749870e55ce',1,'Ogre::ArrayQuaternion::xAxis() const'],['../class_ogre_1_1_array_quaternion.html#ab9c37a58cc12f2c86f68e749870e55ce',1,'Ogre::ArrayQuaternion::xAxis() const'],['../class_ogre_1_1_array_quaternion.html#ab9c37a58cc12f2c86f68e749870e55ce',1,'Ogre::ArrayQuaternion::xAxis() const'],['../class_ogre_1_1_quaternion.html#ac5e21a3d70d015b252b60a4fc95efd1f',1,'Ogre::Quaternion::xAxis()']]],
  ['xclosedisplay_6',['XCloseDisplay',['../_ogre_x11_e_g_l_support_8h.html#a10d83d1f69ba9c38afde9da17cfe2405',1,'OgreX11EGLSupport.h']]],
  ['xcreatecolormap_7',['XCreateColormap',['../_ogre_x11_e_g_l_support_8h.html#a30ae54ad919dae8588835ae717509d0f',1,'OgreX11EGLSupport.h']]],
  ['xcreatewindow_8',['XCreateWindow',['../_ogre_x11_e_g_l_support_8h.html#aa4169ce536fca992c649729b4b80c67a',1,'OgreX11EGLSupport.h']]],
  ['xdestroywindow_9',['XDestroyWindow',['../_ogre_x11_e_g_l_support_8h.html#a3f5a57ad83d1e025553b6857087b9d9b',1,'OgreX11EGLSupport.h']]],
  ['xdisplayname_10',['XDisplayName',['../_ogre_x11_e_g_l_support_8h.html#a55bef2ae3bc74aafa66949a5a31ec583',1,'OgreX11EGLSupport.h']]],
  ['xflush_11',['XFlush',['../_ogre_x11_e_g_l_support_8h.html#a71c8b3499eab93ac47d7952bdf5ec45a',1,'OgreX11EGLSupport.h']]],
  ['xfree_12',['XFree',['../_ogre_x11_e_g_l_support_8h.html#a095580a52a3e5e63f479629c092dc405',1,'OgreX11EGLSupport.h']]],
  ['xgetvisualinfo_13',['XGetVisualInfo',['../_ogre_x11_e_g_l_support_8h.html#ad14dd9fdc11e5d00ab63647cfc3f8a11',1,'OgreX11EGLSupport.h']]],
  ['xgetwindowattributes_14',['XGetWindowAttributes',['../_ogre_x11_e_g_l_support_8h.html#aa563e8e7abd73ce344907eb39dcd181a',1,'OgreX11EGLSupport.h']]],
  ['xinternatom_15',['XInternAtom',['../_ogre_x11_e_g_l_support_8h.html#a10901fada7a1cc5efba300941c79a392',1,'OgreX11EGLSupport.h']]],
  ['xmapwindow_16',['XMapWindow',['../_ogre_x11_e_g_l_support_8h.html#a257afc0c4bb459c2c660630bff44e9db',1,'OgreX11EGLSupport.h']]],
  ['xmovewindow_17',['XMoveWindow',['../_ogre_x11_e_g_l_support_8h.html#a28b3ee0966e12db6cac561ad9ef484d0',1,'OgreX11EGLSupport.h']]],
  ['xopendisplay_18',['XOpenDisplay',['../_ogre_x11_e_g_l_support_8h.html#a51c949ed3a72bf2304f018bbcdcd64f1',1,'OgreX11EGLSupport.h']]],
  ['xqueryextension_19',['XQueryExtension',['../_ogre_x11_e_g_l_support_8h.html#a477dc291ddfcb6c98b4c46dbf205a270',1,'OgreX11EGLSupport.h']]],
  ['xquerytree_20',['XQueryTree',['../_ogre_x11_e_g_l_support_8h.html#a89461d5e0614dfd557804e22100fecee',1,'OgreX11EGLSupport.h']]],
  ['xresizewindow_21',['XResizeWindow',['../_ogre_x11_e_g_l_support_8h.html#adce477cbf3a0b83f5640dd5ebf668904',1,'OgreX11EGLSupport.h']]],
  ['xrrconfigcurrentconfiguration_22',['XRRConfigCurrentConfiguration',['../_ogre_x11_e_g_l_support_8h.html#a5a05a04a82880daeeb842fe1793e3966',1,'OgreX11EGLSupport.h']]],
  ['xrrconfigcurrentrate_23',['XRRConfigCurrentRate',['../_ogre_x11_e_g_l_support_8h.html#a4af046c766176577e90f49fb42987c42',1,'OgreX11EGLSupport.h']]],
  ['xrrconfigrates_24',['XRRConfigRates',['../_ogre_x11_e_g_l_support_8h.html#af5c3b39d44706b903a2c61448a84f132',1,'OgreX11EGLSupport.h']]],
  ['xrrconfigsizes_25',['XRRConfigSizes',['../_ogre_x11_e_g_l_support_8h.html#a144fe29252ef483e8d38a935618b1a5b',1,'OgreX11EGLSupport.h']]],
  ['xrrfreescreenconfiginfo_26',['XRRFreeScreenConfigInfo',['../_ogre_x11_e_g_l_support_8h.html#a54f479b30658bd7e436f6d31339216c3',1,'OgreX11EGLSupport.h']]],
  ['xrrgetscreeninfo_27',['XRRGetScreenInfo',['../_ogre_x11_e_g_l_support_8h.html#a846a80562149754060339388f6f07a4d',1,'OgreX11EGLSupport.h']]],
  ['xrrsetscreenconfigandrate_28',['XRRSetScreenConfigAndRate',['../_ogre_x11_e_g_l_support_8h.html#a8a0543932617c1cc144b66bcd61f421d',1,'OgreX11EGLSupport.h']]],
  ['xsendevent_29',['XSendEvent',['../_ogre_x11_e_g_l_support_8h.html#a199771e2d78de41b3c8a69adaafc4db0',1,'OgreX11EGLSupport.h']]],
  ['xseterrorhandler_30',['XSetErrorHandler',['../_ogre_x11_e_g_l_support_8h.html#a188ca3ae6e59151a2c4c14a99482e97c',1,'OgreX11EGLSupport.h']]],
  ['xsetwmproperties_31',['XSetWMProperties',['../_ogre_x11_e_g_l_support_8h.html#a46c6f72b9036514969671b47377251cb',1,'OgreX11EGLSupport.h']]],
  ['xsetwmprotocols_32',['XSetWMProtocols',['../_ogre_x11_e_g_l_support_8h.html#ad15f704cba03100c7c79f536927aa6c3',1,'OgreX11EGLSupport.h']]],
  ['xstringlisttotextproperty_33',['XStringListToTextProperty',['../_ogre_x11_e_g_l_support_8h.html#a13f1bb8c8d66fd74b2d6a425d76b6716',1,'OgreX11EGLSupport.h']]],
  ['xvisualidfromvisual_34',['XVisualIDFromVisual',['../_ogre_x11_e_g_l_support_8h.html#a5c320d2dfe131dc7e450142e83ee149b',1,'OgreX11EGLSupport.h']]],
  ['xy_35',['xy',['../class_ogre_1_1_vector3.html#acdfb27b5a990112e3f731a2be8a54aec',1,'Ogre::Vector3::xy()'],['../class_ogre_1_1_vector4.html#ad6dc84f0ca8204d16b0232c7609c243c',1,'Ogre::Vector4::xy() const']]],
  ['xyz_36',['xyz',['../class_ogre_1_1_vector4.html#a299d194697fd0ab74fec1961beed0715',1,'Ogre::Vector4']]]
];
